Clarity.Content.Graph (Clarity v0.4.0)

Built-in content provider for graph visualization.

This content provider displays the graph navigation view and is shown for all vertices. It uses Graphviz DOT format to render the current subgraph with zoom controls.

Summary

Functions

render(assigns)

Callback implementation for Phoenix.LiveComponent.render/1.