Clarity.Graph.Tree (Clarity v0.4.0)

Manages a tree-structured digraph that maintains shortest paths from root to all vertices.

This module provides incremental maintenance of a tree graph where each vertex (except root) has exactly one incoming edge, representing the shortest path from the root vertex.