Clarity.Vertex.SourceLocationProvider protocol (Clarity v0.4.0)

Protocol for providing source location information for vertices.

This protocol allows vertices to specify their source file location, which can be used for navigation and debugging purposes.

Summary

Types

t()

All the types that implement this protocol.

Functions

Returns the source location for this vertex, or nil if no location is available.

Types

t()

@type t() :: term()

All the types that implement this protocol.

Functions

source_location(vertex)

@spec source_location(t()) :: Clarity.SourceLocation.t() | nil

Returns the source location for this vertex, or nil if no location is available.