Clarity.Content.Graph (Clarity v0.4.0)
View SourceBuilt-in content provider for graph visualization.
This content provider displays the graph navigation view and is shown for all vertices. It uses Graphviz DOT format to render the current subgraph with zoom controls.
Summary
Functions
Callback implementation for Phoenix.LiveComponent.render/1.
Functions
Callback implementation for Phoenix.LiveComponent.render/1.